#!/usr/bin/python3
#  coding : utf-8
#
#       meshViewerControl
#
#           meshViewerDialogを制御する。
#           起動、コマンド実行、閉じる
#
#   21/08/20    新規作成
#

import subprocess

#-----------------
#  control class
#-----------------
class control:
    """ meshViewerDialogを制御する。
    起動、コマンド実行、閉じる"""

    #
    #  openViewer
    #--------------
    def openViewer(self, caseDir, timeFolder, region):
        """ meshViewerDialogを起動する。 
        """
        #起動する
        comm = "meshViewerDialog.py -case " + caseDir
        comm += " -time " + timeFolder
        comm += " -region " + region
        self.viewer = subprocess.Popen(
            comm,
            shell=True,
            stdin=subprocess.PIPE
            )

    #
    #  runCommand
    #-------------
    def runCommand(self, commLine):
        """ meshViewerにline（コマンドライン）入力する
        途中でCANCELまたは、dialogを閉じた場合は、
        BrokenPipeエラーが発生する。この場合、"CANCEL"が戻る。
        """
        stat = "OK"
        try:
            #subprocessのstdinにlineを出力する
            if commLine[-1] != "\n":
                commLine += "\n"
            commLine = commLine.encode()
            self.viewer.stdin.write(commLine)
            self.viewer.stdin.flush()
        except:
            stat = "CANCEL"
        return stat

    #
    #  runMultiCommands
    #-------------------
    def runMultiCommands(self, commLines):
        """ list形式の複数のコマンドを実行する"""
        stat = "OK"
        for line in commLines:
            stat = self.runCommand(line)
            if stat != "OK":
                break
        return stat

    #
    #  close
    #---------
    def closeViewer(self):
        """ meshViewerDialogを閉じる"""
        self.viewer.stdin.write(b"close\n")
        if self.viewer.poll() == None:
            #BrokenPipeでは無い時にflushする
            self.viewer.stdin.flush()

